window.Gleam.initSearch([{"doc":"minigen","title":"minigen","content":"# minigen\n\nPure random data generation library, appropriate for realistic simulations in the Erlang ecosystem.\n\n## Installation\n\n* For **Erlang** projects, add the dependency into `rebar.config`:\n\n```erlang\n{deps, [\n    {minigen, &quot;0.1.1&quot;}\n]}.\n```\n\n* For **Elixir** projects, add the dependency into `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:minigen, &quot;~&gt; 0.1.1&quot;, manager: :rebar3}\n  ]\nend\n```\n\n* For **Gleam** projects, run `gleam add minigen`.\n\n## Usage\n\nThe examples below use the `run` function that will probably return different values on each call.\nIf we want to get the same values on each call, we need to use `run_with_seed` instead.\n\nDon&#39;t forget to visit https://hexdocs.pm/minigen/minigen.html to see the signature of the available functions:\n`list`, `then`, `always`, `sequence`, `map`, `map2`, `map3`, `map4`, `map5`. Their combination can generate values for any data type.\n\nMore examples can be found in the test directory of the GitHub repository.\n\n### Erlang examples\n\n* Create a random float number\n\n```erlang\nGEN=minigen:float(),\nminigen:run(GEN).\n0.7938520785840248\n```\n\n* Create a random integer number\n\n```erlang\nGEN=minigen:integer(10),\nminigen:run(GEN).\n4\n```\n\n* Create a random boolean value\n\n```erlang\nGEN=minigen:boolean(),\nminigen:run(GEN).\ntrue\n```\n\n* Get a random element from a list\n\n```erlang\nGEN=minigen:element_of_list([1, 2, 3]),\nminigen:run(GEN).\n{ok,2}\n```\n\n```erlang\nGEN=minigen:element_of_list([]),\nminigen:run(GEN).\n{error,nil}\n```\n\n* Shuffle a list\n\n```erlang\nGEN=minigen:shuffled_list([1, 2, 3]),\nminigen:run(GEN).\n[2,1,3]\n```\n\n* Create a random string\n\n```erlang\nGEN=minigen:string(6),\nminigen:run(GEN).\n&quot;3Rzpqd&quot;\n```\n\n### Elixir examples\n\n* Create a random float number\n\n```elixir\n:minigen.float\n|&gt; :minigen.run\n0.36087782004967894\n```\n\n* Create a random integer number\n\n```elixir\n:minigen.integer(10)\n|&gt; :minigen.run\n8\n```\n\n* Create a random boolean value\n\n```elixir\n:minigen.boolean\n|&gt; :minigen.run\nfalse\n```\n\n* Get a random element from a list\n\n```elixir\n:minigen.element_of_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;, &quot;d&quot;])\n|&gt; :minigen.run\n{:ok, &quot;c&quot;}\n```\n\n```elixir\n:minigen.element_of_list([])\n|&gt; :minigen.run\n{:error, nil}\n```\n\n* Shuffle a list\n\n```elixir\n:minigen.shuffled_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;, &quot;d&quot;])\n|&gt; :minigen.run\n[&quot;c&quot;, &quot;d&quot;, &quot;b&quot;, &quot;a&quot;]\n```\n\n* Create a random string\n\n```elixir\n:minigen.string(7)\n|&gt; :minigen.run\n&quot;eJKp8sc&quot;\n```\n\n### Gleam examples\n\n```gleam\nimport minigen\n```\n\n* Create a random float number\n\n```gleam\nminigen.float()\n|&gt; minigen.run\n0.16296012690374562\n```\n\n* Create a random integer number\n\n```gleam\nminigen.integer(10)\n|&gt; minigen.run\n6\n```\n\n* Create a random boolean value\n\n```gleam\nminigen.boolean()\n|&gt; minigen.run\nTrue\n```\n\n* Get a random element from a list\n\n```gleam\nminigen.element_of_list([0.5348931595479329, 0.47372875562526207, 0.7109364198110805])\n|&gt; minigen.run\nOk(0.7109364198110805)\n```\n\n```gleam\nminigen.element_of_list([])\n|&gt; minigen.run\nError(Nil)\n```\n\n* Shuffle a list\n\n```gleam\nminigen.shuffled_list([0.5348931595479329, 0.47372875562526207, 0.7109364198110805])\n|&gt; minigen.run\n[0.47372875562526207, 0.5348931595479329, 0.7109364198110805]\n```\n\n* Create a random string\n\n```gleam\nminigen.string(8)\n|&gt; minigen.run\n&quot;U3j641WL&quot;\n```\n","url":"index.html"},{"doc":"minigen/interop","title":"Algorithm","content":"pub type Algorithm\n\n\nSynonyms:\nminigen/interop.Algorithm\nminigen/interop Algorithm","url":"minigen/interop.html#Algorithm"},{"doc":"minigen/interop","title":"State","content":"pub type State\n\n\nSynonyms:\nminigen/interop.State\nminigen/interop State","url":"minigen/interop.html#State"},{"doc":"minigen/interop","title":"default_algorithm","content":"pub fn default_algorithm() -&gt; Algorithm\n\nSynonyms:\nminigen/interop.default_algorithm\nminigen/interop default_algorithm","url":"minigen/interop.html#default_algorithm"},{"doc":"minigen/interop","title":"seed","content":"pub fn seed(algorithm: Algorithm, int: Int) -&gt; State\n\nSynonyms:\nminigen/interop.seed\nminigen/interop seed","url":"minigen/interop.html#seed"},{"doc":"minigen/interop","title":"seed_s","content":"pub fn seed_s(algorithm: Algorithm) -&gt; State\n\nSynonyms:\nminigen/interop.seed_s\nminigen/interop seed_s","url":"minigen/interop.html#seed_s"},{"doc":"minigen/interop","title":"uniform_s","content":"pub fn uniform_s(state: State) -&gt; #(Float, State)\n\nSynonyms:\nminigen/interop.uniform_s\nminigen/interop uniform_s","url":"minigen/interop.html#uniform_s"},{"doc":"minigen/interop","title":"minigen/interop","content":"","url":"minigen/interop.html"},{"doc":"minigen","title":"Generator","content":"pub type Generator(a) {\n  Generator(fn(Seed) -&gt; #(Seed, a))\n}\n A type for representing generators.\n In order for it to generate data, it should be passed as argument to the `run` or `run_with_seed` function.\nGenerator(fn(Seed) -&gt; #(Seed, a))\n\n\nSynonyms:\nminigen.Generator\nminigen Generator","url":"minigen.html#Generator"},{"doc":"minigen","title":"always","content":"pub fn always(x: a) -&gt; Generator(a)\n\nSynonyms:\nminigen.always\nminigen always","url":"minigen.html#always"},{"doc":"minigen","title":"boolean","content":"pub fn boolean() -&gt; Generator(Bool)\n Creates a generator for boolean values.\n By running it, we get a random boolean value with 50% probability.\n\n  #### Erlang example\n\n erlang\n GEN=minigen:boolean(),\n minigen:run(GEN).\n true\n \n\n  #### Elixir example\n\n elixir\n :minigen.boolean\n |&gt; :minigen.run\n false\n \n\n  #### Gleam example\n\n \n minigen.boolean()\n |&gt; minigen.run\n True\n \n\nSynonyms:\nminigen.boolean\nminigen boolean","url":"minigen.html#boolean"},{"doc":"minigen","title":"element_of_list","content":"pub fn element_of_list(ls: List(a)) -&gt; Generator(Result(a, Nil))\n Creates a generator that randomly selects an element from a list.\n If the list is empty, then we will get an error.\n\n  #### Erlang examples\n\n erlang\n GEN=minigen:element_of_list([1, 2, 3]),\n minigen:run(GEN).\n {ok,2}\n \n\n erlang\n GEN=minigen:element_of_list([]),\n minigen:run(GEN).\n {error,nil}\n \n\n  #### Elixir examples\n\n elixir\n :minigen.element_of_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;, &quot;d&quot;])\n |&gt; :minigen.run\n {:ok, &quot;c&quot;}\n \n\n elixir\n :minigen.element_of_list([])\n |&gt; :minigen.run\n {:error, nil}\n \n  #### Gleam examples\n\n \n minigen.element_of_list([0.5348931595479329, 0.47372875562526207, 0.7109364198110805])\n |&gt; minigen.run\n Ok(0.7109364198110805)\n \n\n \n minigen.element_of_list([])\n |&gt; minigen.run\n Error(Nil)\n \n\nSynonyms:\nminigen.element_of_list\nminigen element_of_list","url":"minigen.html#element_of_list"},{"doc":"minigen","title":"float","content":"pub fn float() -&gt; Generator(Float)\n Creates a generator for float values.\n By running it, we get a random float uniformly distributed between 0.0 (included) and 1.0 (excluded).\n\n  #### Erlang example\n\n erlang\n GEN=minigen:float(),\n minigen:run(GEN).\n 0.7938520785840248\n \n\n  #### Elixir example\n\n elixir\n :minigen.float\n |&gt; :minigen.run\n 0.36087782004967894\n \n\n  #### Gleam example\n\n \n minigen.float()\n |&gt; minigen.run\n 0.16296012690374562\n \n\nSynonyms:\nminigen.float\nminigen float","url":"minigen.html#float"},{"doc":"minigen","title":"integer","content":"pub fn integer(n: Int) -&gt; Generator(Int)\n Creates a generator for integer values.\n By running it, we get a random integer uniformly distributed between 0 (included) and `n` (excluded).\n\n  #### Erlang example\n\n erlang\n GEN=minigen:integer(10),\n minigen:run(GEN).\n 4\n \n\n  #### Elixir example\n\n elixir\n :minigen.integer(10)\n |&gt; :minigen.run\n 8\n \n\n  #### Gleam example\n\n \n minigen.integer(10)\n |&gt; minigen.run\n 6\n \n\nSynonyms:\nminigen.integer\nminigen integer","url":"minigen.html#integer"},{"doc":"minigen","title":"list","content":"pub fn list(gen: Generator(a), n: Int) -&gt; Generator(List(a))\n\nSynonyms:\nminigen.list\nminigen list","url":"minigen.html#list"},{"doc":"minigen","title":"map","content":"pub fn map(gen: Generator(a), fun: fn(a) -&gt; b) -&gt; Generator(b)\n\nSynonyms:\nminigen.map\nminigen map","url":"minigen.html#map"},{"doc":"minigen","title":"map2","content":"pub fn map2(\n  gen_a: Generator(a),\n  gen_b: Generator(b),\n  fun: fn(a, b) -&gt; c,\n) -&gt; Generator(c)\n\nSynonyms:\nminigen.map2\nminigen map2","url":"minigen.html#map2"},{"doc":"minigen","title":"map3","content":"pub fn map3(\n  gen_a: Generator(a),\n  gen_b: Generator(b),\n  gen_c: Generator(c),\n  fun: fn(a, b, c) -&gt; d,\n) -&gt; Generator(d)\n\nSynonyms:\nminigen.map3\nminigen map3","url":"minigen.html#map3"},{"doc":"minigen","title":"map4","content":"pub fn map4(\n  gen_a: Generator(a),\n  gen_b: Generator(b),\n  gen_c: Generator(c),\n  gen_d: Generator(d),\n  fun: fn(a, b, c, d) -&gt; e,\n) -&gt; Generator(e)\n\nSynonyms:\nminigen.map4\nminigen map4","url":"minigen.html#map4"},{"doc":"minigen","title":"map5","content":"pub fn map5(\n  gen_a: Generator(a),\n  gen_b: Generator(b),\n  gen_c: Generator(c),\n  gen_d: Generator(d),\n  gen_e: Generator(e),\n  fun: fn(a, b, c, d, e) -&gt; f,\n) -&gt; Generator(f)\n\nSynonyms:\nminigen.map5\nminigen map5","url":"minigen.html#map5"},{"doc":"minigen","title":"run","content":"pub fn run(gen: Generator(a)) -&gt; a\n Creates pseudorandom data for a generator.\n If we call this function several times, we will probably get different results.\n\n  #### Erlang example\n\n erlang\n GEN=minigen:float(),\n minigen:run(GEN).\n 0.7938520785840248\n \n\n  #### Elixir example\n\n elixir\n :minigen.float\n |&gt; :minigen.run\n 0.36087782004967894\n \n\n  #### Gleam example\n\n \n minigen.float()\n |&gt; minigen.run\n 0.16296012690374562\n \n\nSynonyms:\nminigen.run\nminigen run","url":"minigen.html#run"},{"doc":"minigen","title":"run_with_seed","content":"pub fn run_with_seed(gen: Generator(a), i: Int) -&gt; a\n Creates pseudorandom data for a generator but the result depends on the integer seed value.\n If we call this function several times with the same seed, we will always get the same results.\n\n  #### Erlang example\n\n erlang\n GEN=minigen:float(),\n minigen:run_with_seed(GEN, 1000).\n 0.7109364198110805\n \n\n  #### Elixir example\n\n elixir\n :minigen.float\n |&gt; :minigen.run_with_seed(999)\n 0.4944539429884903\n \n\n  #### Gleam example\n\n \n minigen.float()\n |&gt; minigen.run_with_seed(998)\n 0.29739016530475904\n \n\nSynonyms:\nminigen.run_with_seed\nminigen run_with_seed","url":"minigen.html#run_with_seed"},{"doc":"minigen","title":"sequence","content":"pub fn sequence(gens: List(Generator(a))) -&gt; Generator(List(a))\n\nSynonyms:\nminigen.sequence\nminigen sequence","url":"minigen.html#sequence"},{"doc":"minigen","title":"shuffled_list","content":"pub fn shuffled_list(ls: List(a)) -&gt; Generator(List(a))\n Creates a generator that changes the order of the elements in a list.\n\n  #### Erlang example\n\n erlang\n GEN=minigen:shuffled_list([1, 2, 3]),\n minigen:run(GEN).\n [2,1,3]\n \n\n  #### Elixir example\n\n elixir\n :minigen.shuffled_list([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;, &quot;d&quot;])\n |&gt; :minigen.run\n [&quot;c&quot;, &quot;d&quot;, &quot;b&quot;, &quot;a&quot;]\n \n\n  #### Gleam example\n\n \n minigen.shuffled_list([0.5348931595479329, 0.47372875562526207, 0.7109364198110805])\n |&gt; minigen.run\n [0.47372875562526207, 0.5348931595479329, 0.7109364198110805]\n \n\nSynonyms:\nminigen.shuffled_list\nminigen shuffled_list","url":"minigen.html#shuffled_list"},{"doc":"minigen","title":"string","content":"pub fn string(n: Int) -&gt; Generator(String)\n Creates a generator for string values.\n The generated string will contain `n` alphanumerics.\n\n  #### Erlang example\n\n erlang\n GEN=minigen:string(6),\n minigen:run(GEN).\n &quot;3Rzpqd&quot;\n \n\n  #### Elixir example\n\n elixir\n :minigen.string(7)\n |&gt; :minigen.run\n &quot;eJKp8sc&quot;\n \n\n  #### Gleam example\n\n \n minigen.string(8)\n |&gt; minigen.run\n &quot;U3j641WL&quot;\n \n\nSynonyms:\nminigen.string\nminigen string","url":"minigen.html#string"},{"doc":"minigen","title":"then","content":"pub fn then(\n  gen: Generator(a),\n  fun: fn(a) -&gt; Generator(b),\n) -&gt; Generator(b)\n\nSynonyms:\nminigen.then\nminigen then","url":"minigen.html#then"},{"doc":"minigen","title":"minigen","content":" This module contains some useful functions for generating data in the Erlang ecosystem.\n\n For more information see [this website](https://github.com/mrdimosthenis/minigen).","url":"minigen.html"}]);